@@ -37,6 +37,10 @@ class Domain(SemanthaAPIEndpoint):
     def documents(self):
         return self.__documents
 
+    @property
+    def document_annotations(self):
+        return self.__document_annotations
+
     @property
     def reference_documents(self) -> ReferenceDocuments:
         return self.__reference_documents
@@ -86,31 +90,23 @@ class Domain(SemanthaAPIEndpoint):
         """Get all tags that are defined for the domain"""
         return self._session.get(f"{self._endpoint}/tags").execute().as_list()
 
-    # TODO: move all model/domains endpoints to DoimainModel
-    def get_custom_entity_by_id(self, domain: str, entity: str):
-        return self._session.get(f"/api/model/domains/{domain}/namedentities/{entity}").execute()
-
-    def get_all_regexes(self, domain: str):
-        return self._session.get(f"/api/model/domains/{domain}/regexes").execute()
-
-    def get_regex(self, domain: str, id: str):
-        return self._session.get(f"/api/model/domains/{domain}/regexes/{id}").execute()
 
 
 # TODO: Add docstrings, comments, type hints and error handling.
-class Domains:
+class Domains(SemanthaAPIEndpoint):
     """
         References:
             Specific domains by name
     """
-    def __init__(self, session: RestClient, parent_endpoint: str):
-        self._session = session
-        self.__endpoint = parent_endpoint + "/domains"
+
+    @property
+    def _endpoint(self):
+        return self._parent_endpoint + "/domains"
 
     def get_all(self) -> list[_DomainDTO]:
         """ Get all available domains """
-        return self._session.get(self.__endpoint).execute().to(_DomainsDTO).domains
+        return self._session.get(self._endpoint).execute().to(_DomainsDTO).domains
 
     def get_one(self, domain_name: str) -> Domain:
         # Returns a Domain object for the given domainname, throws error if id doesn't exist
-        return Domain(self._session, self.__endpoint, domain_name)
+        return Domain(self._session, self._endpoint, domain_name)
